@@ -126,9 +126,9 @@ class PanelButton(gtk.ToggleButton):
                 label = "%s\n%s" % (self.activity, self.duration)
             else:
                 label = "%s %s" % (self.activity, self.duration)
-        
-        label = stuff.escape_pango(label)
-        label = '<span gravity=\"south\">' + label + '</span>'
+
+        label = '<span gravity="south">%s</span>' % stuff.escape_pango(label)
+        self.label.set_markup("") #clear - seems to fix the warning
         self.label.set_markup(label)
 
     def get_pos(self):
@@ -532,8 +532,14 @@ class HamsterApplet(object):
         fact_store.clear()
         facts = runtime.storage.get_facts(today)
         
+        if len(facts) > 10:
+            self._gui.get_object("todays_scroll").set_size_request(-1, 250)
+            self._gui.get_object("todays_scroll").set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_ALWAYS)
+        else:
+            self._gui.get_object("todays_scroll").set_size_request(-1, -1)
+            self._gui.get_object("todays_scroll").set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_NEVER)
+            
         by_category = {}
-        
         for fact in facts:
             duration = 24 * 60 * fact["delta"].days + fact["delta"].seconds / 60
             by_category[fact['category']] = \
