@@ -109,7 +109,7 @@ class ReportChooserDialog(gtk.Dialog):
     def show(self, start_date, end_date):
         #set suggested name to something readable, replace backslashes with dots
         #so the name is valid in linux
-        filename = "Time track %s - %s" % (start_date.strftime("%x").replace("/", "."),
+        filename = "Time track %s - %s." % (start_date.strftime("%x").replace("/", "."),
                                            end_date.strftime("%x").replace("/", "."))
         self.dialog.set_current_name(filename)
         
@@ -157,11 +157,20 @@ class ReportChooserDialog(gtk.Dialog):
             format = self.filters[self.dialog.get_filter()]
         path = self.dialog.get_filename()
         
+        # append correct extension if it is missing
+        # TODO - proper way would be to change extension on filter change
+        # only pointer in web is http://www.mail-archive.com/pygtk@daa.com.au/msg08740.html
+        if path.endswith(".%s" % format) == False:
+            path = "%s.%s" % (path.rstrip("."), format)
+        
         categories = []
         for button in self.category_box.get_children():
-            if button.get_active() and button.value:
+            if button.get_active():
                 categories.append(button.value)
         
+        if None in categories:
+            categories = None # nothing is everything
+        
         # format, path, start_date, end_date
         self.emit("report-chosen", format, path,
                            self.start_date.get_date().date(),
@@ -232,7 +241,7 @@ class TimeLine(graphics.Area):
             return
 
         self.fill_area(0, 0, self.width, self.height, (0.975,0.975,0.975))
-        charting.set_color(self.context, (100,100,100))
+        self.set_color((100,100,100))
 
         self.set_value_range(x_min = 1, x_max = (self.end_date - self.start_date).days)        
         month_label_fits = True
@@ -283,9 +292,11 @@ class TimeLine(graphics.Area):
                             total_length += fact["delta"]
                         total_length = total_length.seconds / 60 / 60.0 + total_length.days * 24
                         total_length = total_length / float(self.max_hours) * self.height - 16
-                        self.fill_area(ticker_pos * self.x_factor,
-                                       self.height - total_length,
-                                       self.x_factor, total_length,
+
+                        self.fill_area(round(ticker_pos * self.x_factor),
+                                       round(self.height - total_length),
+                                       round(self.x_factor),
+                                       round(total_length),
                                        (190,190,190))
 
 
@@ -326,7 +337,7 @@ class TimeLine(graphics.Area):
 
 class StatsViewer(object):
     def __init__(self, parent = None):
-        self.parent = parent# determine if app shut shut down on close
+        self.parent = parent# determine if app should shut down on close
         self._gui = stuff.load_ui_file("stats.ui")
         self.window = self.get_widget('stats_window')
         self.stat_facts = None
@@ -337,14 +348,14 @@ class StatsViewer(object):
         
         
         #graphs
-        self.background = (0.975,0.975,0.975)
+        self.background = (0.975, 0.975, 0.975)
         self.get_widget("graph_frame").modify_bg(gtk.STATE_NORMAL,
                       gtk.gdk.Color(*[int(b*65536.0) for b in self.background]))
         self.get_widget("explore_frame").modify_bg(gtk.STATE_NORMAL,
                       gtk.gdk.Color(*[int(b*65536.0) for b in self.background]))
 
 
-        x_offset = 90 # let's nicely align all graphs
+        x_offset = 90 # align all graphs to the left edge
         
         self.category_chart = charting.BarChart(background = self.background,
                                              bar_base_color = (238,221,221),
@@ -501,7 +512,7 @@ class StatsViewer(object):
 
                 self.layout.set_width((self.width) * pango.SCALE)
                 self.context.move_to(0,0)
-                charting.set_color(self.context, charting.dark[8])
+                self.set_color(charting.graphics.Colors.aluminium[5])
                 
                 self.context.show_layout(self.layout)
 
@@ -659,7 +670,7 @@ A week of usage would be nice!"""))
             # date of first record when year has been selected
             # Using python datetime formatting syntax. See:
             # http://docs.python.org/library/time.html#time.strftime
-            first_date = facts[0]["start_time"].strftime(C_("first record", "%(b)s %(d)s"))
+            first_date = facts[0]["start_time"].strftime(C_("first record", "%b %d"))
 
         summary += _("First activity was recorded on %s.") % \
                                                      ("<b>%s</b>" % first_date)
@@ -1278,8 +1289,8 @@ than 15 minutes you seem to be a busy bee." % ("<b>%d</b>" % short_percent))
         
         facts = runtime.storage.get_facts(start_date, end_date, category_id = categories)
         reports.simple(facts,
-                       self.start_date,
-                       self.end_date,
+                       start_date,
+                       end_date,
                        format,
                        path)
 
